% Copyright 2003 by Roger S. Bivand
\name{Map2poly}
\alias{Map2poly}
\alias{Map2lines}
\alias{Map2points}
%\alias{Map2maplim}
\alias{Map2bbs}
\alias{MapShapeIds}
\alias{shape2poly}
\alias{shape2lines}
\alias{shape2points}
%\alias{shp2maplim}
\alias{shape2bbs}
\alias{convert.pl}
%\alias{ringDir}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Create polygon lists and bounding boxes from imported shapefiles}
\description{
  Map2poly() is a function to make imported GIS vector polygons into a "polylist" object from a "Map" object. Map2bbs() retrieves polygon bounding boxes; analogous functions for the "shapefiles" package are shape2poly() and shape2bbs() (thanks to Stphane Dray for his contribution); convert.pl() serves to convert the deprecated "multipart" "polylist" format to an NA-separated format now used by plot() for polylist objects and poly2nb(). 
%\code{ringDir()} attempts to find out whether polygon ring 
%coordinates run clockwise (external boundary of polygon object), or 
%anti-clockwise (internal boundary - hole). 
\code{*2lines()} and \code{*2points()} do the same as \code{*2poly()} for shapefiles of types 3=lines and 1=points; polygons are type=5.
}
\usage{
Map2poly(Map, region.id = NULL, raw=TRUE)
Map2lines(Map)
Map2points(Map)
%Map2maplim(Map)
Map2bbs(Map)
MapShapeIds(Map)
shape2poly(shape, region.id = NULL)
shape2lines(shape)
shape2points(shape)
%shp2maplim(shape)
shape2bbs(shape)
convert.pl(pl)
%ringDir(xy, ring)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Map}{object of class \code{"Map"}, imported from a GIS polygon vector file using unpublished package "maptools"}
  \item{shape}{list returned by \code{read.shapefile()}, imported from a GIS polygon vector file using the package "shapefiles"}
  \item{region.id}{character vector of region ids to be added to the neighbours list as attribute \code{region.id}}
  \item{raw}{default TRUE \emph{until next release}, if TRUE, do not run sanity check for ring directions implying holes in no surrounding polygon}
  \item{pl}{list of old-style multipart polygons of class \code{polylist}}
%  \item{xy}{the coordinate object for a single member of a polygon list}
%  \item{ring}{the ring (one of \code{1:attr(xy, "nParts"))} index number}
}
\details{
  From release 0.4-1, \code{Map2poly} tries to determine a plotting order for multiple parts of a single polygon object, and for lists of polygon objects to avoid overplotting. It also tries to respect the ESRI-stipulated rule that lakes are anti-clockwise and islands are clockwise: \url{http://shapelib.maptools.org/dl/shapefile.pdf}: "The order of vertices or orientation for a ring indicates which side of the ring is the interior of the polygon. The neighborhood to the right of an observer walking along the ring in vertex order is the neighborhood inside the polygon. Vertices of rings defining holes in polygons are in a counterclockwise direction. Vertices for a single, ringed polygon are, therefore, always in clockwise order" (p.8). If raw=FALSE, an additional attempt is made to enforce the final stipulation, where the polygon's bounding box does not fall wholly inside the bounding box of another polygon. This may generate warnings indicating when this has taken place, indicating an unexpected ring direction in the imported shapefile.
}

\value{
  \code{Map2poly}, \code{shape2poly}, \code{convert.pl} return polylist objects, lists of polygon boundary coordinates (divided by NA where the polygon object is represented by more than one polygon) with many attributes;
  \code{Map2lines}, \code{shape2lines} return lineslist objects;
  \code{Map2points}, \code{shape2points} return (n x 2) matrices; and
  \code{Map2bbs}, \code{shape2bbs} return bounding box matrixes, c(x1, y1, x2, y2) with coordinates for the lower left corner and upper right corner.
}

\author{Roger Bivand and Stphane Dray, \email{Roger.Bivand@nhh.no}}
 
\seealso{\code{\link{read.shape}}, \code{\link[shapefiles]{read.shapefile}}}


\examples{
try2 <- read.shape(system.file("shapes/columbus.shp", package="maptools")[1])
mappolys <- Map2poly(try2, as.character(try2$att.data$NEIGNO), raw=FALSE)
plot(mappolys)
title(main="Polygons for Columbus OH from maptools package")
try3 <- read.shape(system.file("shapes/baltim.shp", package="maptools")[1])
baltpts <- Map2points(try3)
xylims <- attr(baltpts, "maplim")
plot(xylims$x, xylims$y, asp=1, type='n', xlab="", ylab="")
points(baltpts)
title(main="Baltimore points from maptools package")
try4 <- read.shape(system.file("shapes/fylk-val.shp", package="maptools")[1])
fylk.val <- Map2lines(try4)
xylims <- attr(fylk.val, "maplim")
plot(xylims$x, xylims$y, asp=1, type='n', xlab="", ylab="")
for (i in 1:length(fylk.val)) lines(fylk.val[[i]])
title(main="Norwegian river centrelines from maptools package")
}

}
\keyword{spatial}

\eof
\name{dbf.read}
\alias{dbf.read}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Read DBF a file}
\description{
  The function reads a DBF file into a data frame, converting character fields to factors, and trying to respect NULL fields.
}
\usage{
dbf.read(filen)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{filen}{name of input file}
}

\value{
  a data frame of data from the DBF file; note that the field names are adjusted to use in R using \code{make.names()}, and so will permit the underscore character from R release 1.9.0.
}

\references{\url{http://shapelib.maptools.org/}}

\author{Nicholas Lewin-Koh and  Roger Bivand; shapelib by Frank Warmerdam}

\note{From maptools 0.4-7, this function is placed in the user-visible namespace on a trial basis, and reports of any malfunction should be sent to the package maintainer, Roger Bivand \email{Roger.Bivand@nhh.no}. It is likely that this function and its arguments will be changed.}

\seealso{\code{\link{read.shape}}}
\examples{
x <- dbf.read(system.file("shapes/sids.dbf", package="maptools")[1])
str(x)
summary(x)
}
\keyword{spatial}

\eof
\name{dbf.write}
\alias{dbf.write}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Write a DBF file}
\description{
  The function tries to write a data frame to a DBF file.
}
\usage{
dbf.write(dataframe, filename, factor2char=TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dataframe}{a data frame object}
  \item{filename}{a file name to be written to}
  \item{factor2char}{logical, default TRUE, convert factor columns to character}
}
\details{
  The function calls code from shapelib to write a DBF format. At present, NAs will cause an error and no file will be written. If factors should be represented as character fields, the data frame must either be pre-processed to convert those colums using \code{I(as.character())}, or the \code{factor2char} argument set to TRUE. In addition logical columns are converted to integer; maximum precision (number of digits including minus sign and decimal sign) for numeric is 19 - scale (digits after the decimal sign) is calculated internally based on the number og digits before the decimal sign.
}
\value{
  no return value.
}
\references{\url{http://shapelib.maptools.org/}}

\author{Nicholas J. Lewin-Koh, modified by Roger Bivand; shapelib by Frank Warmerdam}

\note{From maptools 0.4-7, this function is placed in the user-visible namespace on a trial basis, and reports of any malfunction should be sent to the package maintainer, Roger Bivand \email{Roger.Bivand@nhh.no}. It is likely that this function and its arguments will be changed.}


\seealso{\code{\link{dbf.read}}}
\examples{
data(warpbreaks)
str(warpbreaks)
try1 <- paste(tempfile(), ".dbf", sep="")
dbf.write(warpbreaks, try1, factor2char=FALSE)
in1 <- dbf.read(try1)
str(in1)
try2 <- paste(tempfile(), ".dbf", sep="")
dbf.write(warpbreaks, try2, factor2char=TRUE)
in2 <- dbf.read(try2)
str(in2)
}
\keyword{spatial}

\eof
\name{dotsInPolys}
\alias{dotsInPolys}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Put dots in polygons}
\description{
  Make a list of point coordinate matrices for a dot density map
}
\usage{
dotsInPolys(pl, x, f = csr)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{pl}{list of polygons of class \code{polylist}}
  \item{x}{integer vector of counts of same length as pl for dots}
  \item{f}{function to place points in polygons, either \code{csr} - completely spatially random or \code{gridpts} gridded points from the splancs package}
}
\details{
 With f=csr (completely spatially random), the dots are placed in the polygon at random, f=gridpts - in a grid pattern (number of dots not guaranteed to be the same as the count). When the polygon is made up of more than one part, the dots will be placed in proportion to the relative areas of the clockwise rings (anticlockwise are taken as holes). No correction is made for holes in the placing of the dots. 
}
\value{
  The function returns a list of matrices of point coordinates, one matrix for each member of pl. If x[i] is zero, the list element is NULL, and can be tested when plotting - see the examples.
}

\note{Waller and Gotway (2004) Applied Spatial Statistics for Public Health Data (Wiley, Hoboken, NJ) explicitly warn that care is needed in plotting and interpreting dot density maps (pp. 81-83)}

\author{Roger Bivand \email{Roger.Bivand@nhh.no}}

\seealso{\code{\link[splancs]{csr}}, \code{\link[splancs]{gridpts}}}
\examples{
x <- read.shape(system.file("shapes/sids.shp", package="maptools")[1])
ncpolys <- Map2poly(x, raw=FALSE)
try1 <- dotsInPolys(ncpolys, as.integer(x$att.data$SID74))
plot(ncpolys)
xx <- lapply(try1, function(x) {if (!is.null(x)) points(x, pch=18, col="red")})
try2 <- dotsInPolys(ncpolys, as.integer(x$att.data$SID74), f=gridpts)
plot(ncpolys)
xx <- lapply(try2, function(x) {if (!is.null(x)) points(x, pch=18, col="red")})
}
\keyword{spatial}


\eof
\name{get.Pcent}
\alias{get.Pcent}
\title{Polygon centroids}
\description{
  return the centroids of a map of polygons
}
\usage{
get.Pcent(theMap)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{theMap}{a Map object returned by read.shape()}
}

\value{
 a matrix of centroids.
}

\author{Nicholas J. Lewin-Koh, modified by Roger Bivand \email{Roger.Bivand@nhh.no}}

\examples{
x <- read.shape(system.file("shapes/sids.shp", package="maptools")[1])
get.Pcent(x)
}
\keyword{spatial}


\eof
\name{gpcholes}
\alias{gpcholes}
\alias{hole1pl}
\alias{hole2pl}

\docType{data}
\title{Hisaji Ono's lake/hole problem}
\description{
  How to plot polygons with holes - holes are encoded by coordinates going anticlockwise, and overplotting is avoided by re-ordering the order in which polygons are plotted.
}
\usage{data(gpcholes)}
\format{
  The format is class \code{"polylist"}.
}

\details{

"Date: Tue, 11 May 2004 12:54:20 +0900
From: Hisaji ONO 
To: r-help

 I've tried to create a polygon with one hole by gpclib using following
example script.

 holepoly <- read.polyfile(system.file("poly-ex/hole-poly.txt", package="gpclib"), nohole = FALSE)
 area.poly(holepoly)
 plot(holepoly,poly.args=list(col="red",border="blue"))

 And I noticed plot function couldn't draw polygons with holes correctly.

 Does anyone know how to solve this situation?"

*(hole1pl has reversed the y component of polygon 1, to make its ring direction clockwise, hole2pl reverses the order of the two polygons in holepoly1@pts)*

}

\source{
  Data file included in "gpclib" package.
}

\examples{
data(gpcholes)
plot(hole2pl, col="red", pbg="white", border="blue", forcefill=FALSE)
plot(hole1pl, col="red", pbg="white", border="blue", forcefill=FALSE)
}

\keyword{datasets}

\eof
\name{maptools}
\alias{maptools}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Report version information and changes}
\description{
  Access version information and changes
}
\usage{
maptools(changes = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{changes}{If TRUE, reports changes, most recent last}
}

\value{
  Invisibly returns the change list, with members version and changes
  
}
\author{Roger Bivand}

\examples{
maptools(changes=TRUE)
}
\keyword{spatial}

\eof
\name{plot.Map}
\alias{plot.Map}
%\alias{color.ramp}

\title{Plot a Map object}
\description{
  The function plots a map object directly from the imported shapefile data.
}
\usage{
plot.Map(x, recs, auxvar = NULL, add = FALSE, fg = "gray", ol = "black", 
  prbg = NULL, glyph = 16, color='red', type = "q", nclass = 5, ...)
%color.ramp(nclass, color='red', nvec=NULL, type='q')
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{a Map object returned by read.shape()}
  \item{recs}{a vector with the shapes to plot, if missing defaults to all shapes; if fg is not equal to the length of recs, all fg are set to fg[1]}
  \item{auxvar}{if the Map has polygon shapes, a variable from which to derive polygon fill colours using the computed class intervals, must be same length as number of shapes}
  \item{add}{default FALSE, if TRUE add to existing plot}
  \item{fg}{foreground colour, can be used to pass through point and polygon colours, permitting the built-in class interval calculation to be avoided; if fg is not equal to the length of recs, all fg are set to fg[1]}
  \item{ol}{line/boundary colour}
  \item{prbg}{if not NULL, draw a rectangle around the plot in this colour}
  \item{glyph}{points plotted as this pch code}
  \item{color}{base colour for color.ramp(); default "red"}
  \item{type}{default "q" for quantile classes for color.ramp(), can also be "e" for equal intervals}
  \item{nclass}{number of classes for class intervals}
  \item{\dots}{passed through to plotting functions}
%  \item{color}{default "red"}
%  \item{nvec}{data vector to convert to class intervals}
}

\value{
  If the \code{auxvar} variable is not used, the function returns NULL, otherwise it returns the list constructed by \code{maptools:::color.ramp()} with components:
  \item{ramp}{vector of colours}
  \item{col.class}{vector of classes}
  \item{breaks}{class intervals given as argument to cut}
}

\author{Nicholas J. Lewin-Koh, modified by Roger Bivand \email{Roger.Bivand@nhh.no}}

\seealso{\code{\link{read.shape}}}
\examples{
x <- read.shape(system.file("shapes/sids.shp", package="maptools")[1])
plot(x)
nParts <- sapply(x$Shapes, function(x) attr(x, "nPart"))
table(nParts)
cols <- c("azure", "blue", "orange")
fgs <- cols[nParts]
plot(x, fg=fgs)
res <- plot(x, auxvar=x$att.data$BIR74)
str(res)
res <- plot(x, auxvar=x$att.data$BIR74, type="e")
str(res)
}
\keyword{spatial}


\eof
% Copyright 2001-4 by Roger S. Bivand
\name{plot.polylist}
\alias{plotpolys}
\alias{plot.polylist}
\alias{leglabs}
\title{Plot polygons}
\description{
A helper function for plotting polygons in a global bounding box, attempts to handle overplotting internally, holes should be coded by coordinates ordered anti-clockwise. Earlier behaviour requires forcefill=TRUE; this is now default, but will cease to be so from next release. Changes caused by some imported shapefiles data leading to erroneously plotting lakes/islands, and R polygon() overplotting internal polygons. 
\code{leglabs} makes character strings from the same break points. The \code{plot.polylist()} function may be used as a generic S3 method. NOTE! \code{plotpolys()} DEPRECATED: use generic plot() for polylist objects function instead.
}
\usage{
plot.polylist(x, col, border = par("fg"), add = FALSE, xlim=NULL,
 ylim=NULL, xlab = "", ylab = "", xpd = NULL, density = NULL, angle = 45, 
 pbg=NULL, forcefill=TRUE, ...)
leglabs(vec, under="under", over="over", between="-")
plotpolys(pl, bb, col = NA, border = par("fg"), add = FALSE, xlim, ylim, ...)
}

\arguments{
  \item{pl, x}{list of polygons of class \code{polylist}}
  \item{bb}{matrix of polygon bounding boxes - columns are LL(x), LL(y), UR(x), UR(y); note that this argument may be omitted if the polygon list object has an "maplim" attribute, or if both xlim and ylim arguments are given}
  \item{col}{colurs to use for filling the polygons}
  \item{border}{the color to draw the border}
  \item{add}{add to existing plot}
  \item{xlim, ylim}{numeric of length 2, giving the x and y coordinates ranges}
  \item{xlab, ylab}{x and y axis labels, default no label}
  \item{xpd}{(where) should clipping take place?}
  \item{density}{the density of shading lines, in lines per inch}
  \item{angle}{the slope of shading lines, given as an angle in degrees (counter-clockwise)}
  \item{pbg}{colour to be used for hole and background fill, by default NULL (note that par("bg") may be "transparent")}
  \item{forcefill}{default TRUE \emph{until next release} - fill anyway, if FALSE: believe ring direction as indication of holes/lakes}
  \item{...}{other arguments passed to plot to set the plot window - not passed to polygon}
  \item{vec}{vector of break values}
  \item{under}{character value for under}
  \item{over}{character value for over}
  \item{between}{character value for between}
%  \item{y}{numeric vector to be broken into class intervals}
%  \item{rightmost.closed}{as in findInterval()}
%  \item{all.inside}{as in findInterval()}
}
\author{Roger Bivand \email{Roger.Bivand@nhh.no}}

\seealso{\code{\link{Map2poly}}, \code{\link{findInterval}}}

\examples{
try2 <- read.shape(system.file("shapes/columbus.shp", package="maptools")[1])
mappolys <- Map2poly(try2, as.character(try2$att.data$NEIGNO), raw=FALSE)
brks <- round(quantile(try2$att.data$CRIME, probs=seq(0,1,0.2)), digits=2)
colours <- c("salmon1", "salmon2", "red3", "brown", "black")
plot(mappolys, col=colours[findInterval(try2$att.data$CRIME, brks, all.inside=TRUE)], forcefill=FALSE)
legend(x=c(5.8, 7.1), y=c(13, 14.5), legend=leglabs(brks),
  fill=colours, bty="n")
title(main=paste("Columbus OH: residential burglaries and vehicle\nthefts",
  "per thousand households, 1980"))
try3 <- read.shape(system.file("shapes/sids.shp", package="maptools")[1])
mappolys <- Map2poly(try3, as.character(try3$att.data$FIPSNO), raw=FALSE)
cols <- c("pink", "orange", "red")
np <- sapply(mappolys, function(x) attr(x, "nPart"))
plot(mappolys, col=cols[np], forcefill=FALSE)
title(main="White: one part, orange: two part, red: three part polygons")
plot(mappolys, density=c(10, 20, 30)[np], angle=c(-45, 0, 45)[np], axes=FALSE, forcefill=FALSE)
}
\keyword{spatial}

\eof
\name{read.shape}
\alias{read.shape}
\alias{getinfo.shape}
\alias{print.shapehead}

\title{Read shapefile into Map object}
\description{
  Read shapefile into Map object; the file should be given including its ".shp" extension, and the function will reconstruct the names of the database (dbf) file and the index (shx) file from these.
}
\usage{
read.shape(filen, dbf.data = TRUE, verbose=TRUE)
getinfo.shape(filen)
print.shapehead(x, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{filen}{name of file with *.shp extension}
  \item{dbf.data}{read DBF data together with shapes, default TRUE}
  \item{verbose}{default TRUE --- report type of shapefile and number of shapes}
  \item{x}{a shapehead list as returned by getinfo.shape}
  \item{...}{other arguments passed to print}
}
\details{
  The function calls code from shapelib to read shapefiles, a file format used by ESRI GIS software among others
}
\value{
read.shape() returns either a list of shapes of class ShapeList, or if dbf.data = TRUE a Map object with:
  \item{Shapes}{a list of shapes of class ShapeList; both the individual shapes and the list have attributes}
  \item{att.data}{a data frame of data from the associated DBF file; note that the field names are adjusted to use in R using \code{make.names()}, and so will permit the underscore character from R release 1.9.0.}
}
\references{\url{http://shapelib.maptools.org/}}
\author{Nicholas J. Lewin-Koh, modified by Roger Bivand \email{Roger.Bivand@nhh.no}; shapelib by Frank Warmerdam}

\seealso{\code{\link{plot.Map}}}
\examples{
x <- read.shape(system.file("shapes/sids.shp", package="maptools")[1])
length(x$Shapes)
unlist(lapply(x$att.data, class))
str(getinfo.shape(system.file("shapes/fylk-val.shp", package="maptools")[1]))
}
\keyword{spatial}


\eof
% Copyright 2003 by Roger S. Bivand
\name{subset.polylist}
\alias{subset.polylist}
\title{Subset polygon list objects}
\description{
  The function subsets a polygon list object, also subsetting region ID attributes and also map limits if required.
}
\usage{
subset.polylist(x, subset, fit.bbox = TRUE, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{a polylist object}
  \item{subset}{a logical vector valued TRUE if the element is to be retained}
  \item{fit.bbox}{if TRUE (default) modifies the maplim attribute to bound the subset}
  \item{...}{other arguments passed through}
}

\value{
  returns a polylist object, lists of polygon boundary coordinates (divided by NA where the polygon object is represented by more than one polygon);
}

\author{Roger Bivand \email{Roger.Bivand@nhh.no}}

\examples{
nc <- read.shape(system.file("shapes/sids.shp", package = "maptools")[1])
mappolys <- Map2poly(nc, as.character(nc$att.data$FIPSNO))
submap <- subset(mappolys, nc$att.data$SID74 > 0)
plot(mappolys, col="orange")
plot(submap, add=TRUE, col="lightpink", forcefill=TRUE)
}
\keyword{spatial}


\eof
\name{symbolsInPolys}
\alias{symbolsInPolys}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Place grids of points over polygons}
\description{
  Place grids of points over polygons with chosen density and/or symbols (suggested by Michael Wolf) - the function uses functions from the splancs package internally.
}
\usage{
symbolsInPolys(pl, dens, symb = "+")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{pl}{list of polygons of class \code{polylist}}
  \item{dens}{number of symbol plotting points per unit area; either a single numerical value for all polygons, or a numeric vector the same length as pl with values for each polygon}
  \item{symb}{plotting symbol; either a single value for all polygons, or a vector the same length as pl with values for each polygon}
}
\details{
  The dots are placed in a grid pattern with the number of points per polygon being polygon area times density (number of dots not guaranteed to be the same as the count). When the polygon is made up of more than one part, the dots will be placed in proportion to the relative areas of the clockwise rings (anticlockwise are taken as holes). No correction is made for holes in the placing of the dots. 
}

\value{
The function returns a list of matrices of point coordinates, one matrix for each member of pl; each matrix has a \code{symb} attribute that can be used for setting the \code{pch} argument for plotting. If the count of points for the given density and polygon area is zero, the list element is NULL, and can be tested when plotting - see the examples.
}

\note{Extension to plot pixmaps at the plotting points using addlogo() from the pixmap package is left as an exercise for the user.}

\author{Roger Bivand \email{Roger.Bivand@nhh.no}}

\seealso{\code{\link[splancs]{areapl}}, \code{\link[splancs]{gridpts}}}

\examples{
x <- read.shape(system.file("shapes/sids.shp", package="maptools")[1])
ncpolys <- Map2poly(x, raw=FALSE)
np <- sapply(ncpolys, function(x) attr(x, "nPart"))
symbs <- c("-", "+", "*")
try1 <- symbolsInPolys(ncpolys, 70, symb=symbs[np])
plot(ncpolys)
xx <- lapply(try1, function(x) {if (!is.null(x)) points(x, pch=attr(x, "symb"))})
}
\keyword{spatial}


\eof
\name{write.pointShape}
\alias{write.pointShape}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Write a point-type shapefile}
\description{
  The function calls code from shapelib to write a point-type shapefile.
}
\usage{
write.pointShape(object, file, coordinates, factor2char = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object}{a data frame object}
  \item{file}{a file name of maximum 8 chararacters, numbers or the underscore symbol to be written, omitting the extensions *.shp, *.shx and *.dbf, which are added in the function}
  \item{coordinates}{a 2-column numeric matrix of coordinates}
  \item{factor2char}{logical, default TRUE, convert factor columns to character}
}

\details{
  The function calls code from shapelib to write a point-type shapefile (both the geometry file with a *.shp extension, the index file with a *.shx extension, and the database file with a *.dbf extension - see \code{\link{dbf.write}} for details of the data frame export within this function.
}
\value{
  no return value.
}

\references{\url{http://shapelib.maptools.org/}}

\author{Nicholas J. Lewin-Koh, modified by Roger Bivand; shapelib by Frank Warmerdam}

\note{From maptools 0.4-7, this function is placed in the user-visible namespace on a trial basis, and reports of any malfunction should be sent to the package maintainer, Roger Bivand \email{Roger.Bivand@nhh.no}. It is likely that this function and its arguments will be changed.}

\seealso{\code{\link{dbf.write}}}
\examples{
balt_orig <- read.shape(system.file("shapes/baltim.shp", package="maptools")[1])
plot(balt_orig)
balt_df <- balt_orig$att.data
balt_cheap <- balt_df[balt_df$PRICE < 40,]
file <- tempfile("")
write.pointShape(balt_cheap, file, coordinates=cbind(balt_cheap$X, balt_cheap$Y))
getinfo.shape(paste(file, ".shp", sep=""))
balt_new <- read.shape(paste(file, ".shp", sep=""))
plot(balt_new, fg="red", glyph=1, add=TRUE)
}
\keyword{spatial}


\eof
\name{write.polylistShape}
\alias{write.polylistShape}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Write a polygon-type shapefile}
\description{
  The function calls code from shapelib to write a polygon-type shapefile from an S3 polylist object.
}
\usage{
write.polylistShape(polylist, df, file, factor2char = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{polylist}{list of polygons of class \code{polylist}}
  \item{df}{a data frame object}
  \item{file}{a file name of maximum 8 chararacters, numbers or the underscore symbol to be written, omitting the extensions *.shp, *.shx and *.dbf, which are added in the function}
  \item{factor2char}{logical, default TRUE, convert factor columns to character}
}
\details{
  The function calls code from shapelib to write a point-type shapefile (both the geometry file with a *.shp extension, the index file with a *.shx extension, and the database file with a *.dbf extension - see \code{\link{dbf.write}} for details of the data frame export within this function.
}
\value{
  no return value.
}
\references{\url{http://shapelib.maptools.org/}}

\author{Nicholas J. Lewin-Koh, modified by Roger Bivand; shapelib by Frank Warmerdam}

\note{From maptools 0.4-7, this function is placed in the user-visible namespace on a trial basis, and reports of any malfunction should be sent to the package maintainer, Roger Bivand \email{Roger.Bivand@nhh.no}. It is likely that this function and its arguments will be changed.}

\seealso{\code{\link{write.pointShape}}, \code{\link{dbf.write}}}
\examples{
col_orig <- read.shape(system.file("shapes/columbus.shp", package="maptools")[1])
mappolys <- Map2poly(col_orig, as.character(col_orig$att.data$NEIGNO), raw=FALSE)
plot(mappolys)
col_df <- col_orig$att.data
col_cheap <- subset(mappolys, col_df$HOVAL < 34)
col_df_cheap <- subset(col_df, col_df$HOVAL < 34)
file <- tempfile("")
write.polylistShape(col_cheap, col_df_cheap, file)
getinfo.shape(paste(file, ".shp", sep=""))
col_new <- read.shape(paste(file, ".shp", sep=""))
mappolys <- Map2poly(col_new, as.character(col_new$att.data$NEIGNO), raw=FALSE)
plot(mappolys, border="red", add=TRUE)
}
\keyword{spatial}


\eof
